stacd.data <-
function(betas,x=NULL,z=NULL,n=NULL,ncase=NULL,ncontrol=NULL,pa=NULL,pb=NULL,model="logistic",ve=NULL,verbose=FALSE){

	#####
	# Validate input 
	# if needed, x,z generated from rbinom(n,2,p)
	#####

	B.V <- betas

	if(!(length(B.V)==9)){
		stop("B.V must be a vector of the 9 parameter values for the STACD model")
	}
	if(!is.numeric(B.V)){
		stop("The parameter values in B.V must be numeric")
	}
	if(any(is.na(B.V))){
		stop("All parameter values must be specified in B.V")
	}
	
	if(!is.null(x)){
		if(!is.numeric(x)){
			stop("Input data must be numeric")
		}
		if(any(is.na(match(x,c(0,1,2,NA))))){
			stop("Invalid values in x. All values must be 0,1,2, or NA.")
		}
		if(!is.null(pa)){
			warning("Data given for first locus. Ignoring allele frequency pa")
			pa <- NULL
		}
		if(!is.null(n) || !is.null(ncase) || !is.null(ncontrol)){
			warning("Sample size is ignored when data is provided for either locus")
		}
		n <- length(x)
		if(!is.null(z)){
			if(!is.numeric(z)){
				stop("Input data must be numeric")
			}
			if(any(is.na(match(z,c(0,1,2,NA))))){
				stop("Invalid values in z. All values must be 0,1,2, or NA.")
			}
			if(length(z)!=n){
				stop("Data for SNPs x and z must be of the same dimension")
			}
			if(!is.null(pb)){
				warning("Data given for second locus. Ignoring allele frequency pb")
				pb <- NULL
			}
		}else{
			if(is.null(pb)){
				stop("Need to provide either data or allele frequency for the second locus")
			}
			if(length(pb)>1 || !is.numeric(pb)){
				stop("pb must be a single numeric value giving allele frequency between 0 and 1")
			}
			z <- rbinom(n,2,pb)
		}
	}else{
		if(is.null(pa)){
			stop("Need to provide either data or allele frequency for the first locus")
		}
		if(length(pa)>1 || !is.numeric(pa)){
			stop("pa must be a single numeric value giving allele frequency between 0 and 1")
		}
		if(!is.null(z)){
			if(!is.numeric(z)){
				stop("Input data must be numeric")
			}
			if(any(is.na(match(z,c(0,1,2,NA))))){
				stop("Invalid values in z. All values must be 0,1,2, or NA.")
			}
			if(!is.null(pb)){
				warning("Data given for second locus. Ignoring allele frequency pb")
				pb <- NULL
			}
			if(!is.null(n) || !is.null(ncase) || !is.null(ncontrol)){
				warning("Sample size is ignored when data is provided for either locus")
			}
			n <- length(z)
			x <- rbinom(n,2,pa)
		}else{
			if(is.null(pb)){
				stop("Need to provide either data or allele frequency for the second locus")
			}
			if(length(pb)>1 || !is.numeric(pb)){
				stop("pb must be a single numeric value giving allele frequency between 0 and 1")
			}

			if(is.null(n) && is.null(ncase) && is.null(ncontrol) ){
				stop("Must provide sample size to generate SNP data")
			}else{
				if(!is.null(n)){
					if(!is.null(ncase) || !is.null(ncontrol)){
						stop("Must specify either \"n\" or number of cases and controls, not both")
					}
				}else{
					if(!(model=="logistic")){
						stop("Cases and controls can only be specified for the logistic model")
					}
					if(is.null(ncase) || is.null(ncontrol)){
						stop("Number of both cases and controls must be specified")
					}
					n <- ncase + ncontrol
				}
			}
			x <- rbinom(n,2,pa)
			z <- rbinom(n,2,pb)
		}
	}

	if(!(model=="logistic") && !(model=="normal")){
		warning("Model form must be \"logistic\" or \"normal\". Defaulting to \"logistic\".")
		model <- "logistic"
	}

	if(is.null(ve)){
		ve <- NA
	}

	####
	# get model information
	####

	# if using provided data, use empirical allele freqs
	if(is.null(pa)){
		pa <- mean(x,na.rm=TRUE)/2
	}
	if(is.null(pb)){
		pb <- mean(z,na.rm=TRUE)/2
	}

	mod <- stacd.model(betas=B.V,pa=pa,pb=pb,model=model,ve=ve)

	####
	# get design matrix
	####

	dat.M <- stacd.design(x,z)

	####
	# compute linear model
	####

	ytrue <- cbind(rep(1,n),as.matrix(dat.M)) %*% matrix(betas,ncol=1)

	####
	# add error, dichotomize if needed
	####

	if(model=="normal"){
		ve <- mod$error_variance
		y <- ytrue+rnorm(n,sd=sqrt(ve))
	}else if(model=="logistic"){
		ve <- (pi^2)/3
		ystar <- ytrue+rlogis(n)
		yprob <- exp(ystar)/(1+exp(ystar))
		y <- rbinom(n,1,yprob)
	}

	#####
	# loop for case/control if needed
	#####

	if(model=="logistic" && !is.null(ncase) && !is.null(ncontrol)){

		# loop to get enough cases and controls
		while(sum(y)<ncase || sum(!y)<ncontrol){
			# generate more data
			xnew <- rbinom(n,2,pa)
			znew <- rbinom(n,2,pb)
			newdat.M <- stacd.design(xnew,znew)
			newytrue <- cbind(rep(1,n),as.matrix(newdat.M)) %*% matrix(betas,ncol=1)
			newystar <- ytrue+rlogis(n)
			newyprob <- exp(newystar)/(1+exp(newystar))
			newy <- rbinom(n,1,newyprob)

			# append to existing
			y <- c(y,newy)
			yprob <- c(yprob,newyprob)
			ystar <- c(ystar,newystar)
			ytrue <- c(ytrue,newytrue)
			x <- c(x,xnew)
			z <- c(z,znew)
		}

		# reduce to target total sample size if needed
		if(length(y)>(ncase+ncontrol)){
			case <- which(y==1)
			control <- which(y==0)
			pickcase <- sample(case,ncase,replace=F)
			pickcontrol <- sample(control,ncontrol,replace=F)
			saved <- sort(c(pickcase,pickcontrol))
			
			y <- y[saved]
			yprob <- yprob[saved]
			ystar <- ystar[saved]
			ytrue <- ytrue[saved]
			x <- x[saved]
			z <- z[saved]
		}
	}

	####
	# Format, output
	####

	if(verbose){
		if(model=="normal"){
			fulldat <- data.frame(y=y,XB=ytrue,x=x,z=z)
		}else if(model=="logistic"){ 
			fulldat <- data.frame(y=y,ystar=ystar,XB=ytrue,yprob=yprob,x=x,z=z)
		}
		out <- list(Full_Data=fulldat,Model_Info=mod)
		return(out)
	}else{
		outdat <- data.frame(y=y,x=x,z=z)
		return(outdat)
	}
}

