\name{logodds.to.stacd}
\alias{pen.to.stacd}
\alias{logodds.to.stacd}
\concept{convert models}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Convert penetrance or log odds model to STACD parameters
}
\description{
Two-locus interaction models are commonly presented as using penetrances or log odds ratios. These function expresses any given two-locus penetrance or log odds ratio model in terms of the STACD model parameters. Additional information about the model is then provided based on the STACD model parameters.
}
\usage{
pen.to.stacd(pen.M, pa = NULL, pb = NULL)
logodds.to.stacd(logodds.M, pa = NULL, pb = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{pen.M}{
A 3x3 matrix containing the penetrances (\emph{P(y=1)} conditional on the genotypes) for the model. The columns of the matrix should correspond to the genotype at the first locus, and the rows should correspond to the genotype at the second locus.
}
  \item{logodds.M}{
A 3x3 matrix containing the log odds ratios (\emph{ln[P(y=1)/(1-P(y=1))]} conditional on the genotypes) for the model. The columns of the matrix should correspond to the genotype at the first locus, and the rows should correspond to the genotype at the second locus.
}
  \item{pa}{
(optional) allele frequency for the first locus. If omitted, defaults to .5 with a warning.

}
  \item{pb}{
(optional) allele frequency for the second locus. If omitted, defaults to .5 with a warning.
}
}
\details{
STACD model parameters are computed using just the provided penetrance model. All other information about the model (marginals, variance decomposition) requires that the allele frequencies also be specified. If allele frequencies \code{pa} and/or \code{pb} are not given, then an allele frequncy of 0.5 is assumed, with a warning. 

The two loci for the penetrance model are assumed to be biallelic, unlinked, and under Hardy-Weinberg equilibrium. The variance decomposition assumes the dichotomous phenotype results from thresholding a continuous latent variable with logistically-distributed errors.
}
\value{
\item{Betas}{STACD model parameters}
\item{Variance_Explained}{a list with elements:

\code{Multiple_R_Sq} - total proportion of variance explained by ther model, as per McKelvey & Zavoina (1975). 
 
\code{Parameter_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the STACD paramters

\code{Cockerham_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the conventional decomposition given by Cockerham (1954).}
\item{Penetrances}{the provided 3x3 penetrance matrix}
\item{Marginals}{length 3 vectors of the marginal pentrance conditional on the first locus and on the second locus}
\item{Prevalence}{expected prevalence of the dichotmoous phenotype}
\item{Var_ystar}{variance of the continuous variable underlying the phenotype}
}
\references{
Cockerham, C. C. (1954). An extension of the concept of partitioning hereditary variance for analysis of covariance among relatives when epistasis is present. \emph{Genetics}, 39: 859-882.

McKelvey, R., and Zavoina, W. (1975). A Statistical model for the analysis of ordinal level dependent variables. \emph{Journal of Mathematical Sociology}, 4: 103-120.

Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.
}
\author{
Raymond Walters, Charles Laurin
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
To compute a penetrance model from STACD parameters see \code{\link{stacd.model}} 
}
\examples{
# Example from Walters et al using log odds model
# adapted from data in Bolton et al 2010
exvarex <- logodds.to.stacd(logodds.M=matrix(c(0,0,0, 0,0,.25, 0,0,1),3,3,byrow=TRUE),
                            pa=0.3, pb=0.3)
print(exvarex$Betas)
print(exvarex$Variance_Explained)

# Example using the Modifying Effect Model
pen.M <- matrix(c(.01,.01,.01,
				.01,.01,.02,
				.02,.02,.02),3,3,byrow=TRUE)
pen.to.stacd(pen.M,pa=.3,pb=.5)

# without specifying allele frequncy, defaults to .5 for both loci
mod1 <- pen.to.stacd(pen.M)
mod2 <- pen.to.stacd(pen.M,pa=.5,pb=.5)
all.equal(mod1,mod2)
}
\keyword{ models }
