\name{stacd.model}
\alias{stacd.model}
\concept{convert models}
\concept{variance decomposition}
\title{
Information about STACD model
}
\description{
Based on the parameters for the STACD model it is possible to compute an array of information regarding the expected distribution of the phenotype. Specifically, we provide the conditional and marginal expected values for the phenotype, and the decomposition of the variance explained by the two loci. 
}
\usage{
stacd.model(betas, pa = NA, pb = NA, model = "logistic", ve = NA)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{betas}{
a length 9 numeric vector of the STACD model parameters (in order: \emph{mu}, \emph{alpha_1}, \emph{alpha_2}, \emph{beta_1}, \emph{beta2}, \emph{gamma_ab}, \emph{gamma^*_aab}, \emph{gamma^*_abb}, and \emph{gamma^*_aabb})
}
  \item{pa}{
(optional) allele frequency for the first locus. If omitted, defaults to .5 with a warning.
}
  \item{pb}{
(optional) allele frequency for the second locus. If omitted, defaults to .5 with a warning.
}
  \item{model}{
either "normal" or "logistic" specifying the scale of the STACD model. If "normal", then the phenotype is assumed to be continuous with normally distributed errors. If "logistic", then the phenotype is assumed to be dichotomous based on an underlying continuous variable with logistically distributed errors.
}
  \item{ve}{
the variance of the error term in the normal model. If not specified, it will be set so that the total phenotypic variance is 1. If model="logistic", this argument is ignored (with a warning).
}
}
\details{
Conditional expected values and variance decomposition are computed based on the model parameters and the allele frequencies. If allele frequencies \code{pa} and \code{pb} are not given they are assumed to be 0.5 (with a warning). The two loci are assumed to be uncorrelated.

For the logistic model, the variance decomposition is based on the latent variable \code{y_star}, as is consistent with the pseudo-R^2 for logistic regression introduced by McKelvey & Zavoina (1975). The variable \code{y_star} is assume to be continuous with errors following a standard logistic distribution; the dichotmous phenotype $y$ is created by thresholding this variable. 

The two loci for the STACD model are assumed to be biallelic, unlinked, and under Hardy-Weinberg equilibrium. 
}
\value{
\item{Betas}{STACD model parameters}
\item{Variance_Explained}{a list with elements:

\code{Multiple_R_Sq} - total proportion of variance explained by ther model
 
\code{Parameter_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the STACD paramters

\code{Cockerham_Decomp} - a length 8 vector giving the decomposition of the proportion of variance explained based on the conventional decomposition given by Cockerham (1954).}

In addition, information about the conditional expected values and error variance the phenotype is computed. The format for this information depends on whether the "normal" or "logistic" model is specified. For the logistic model, the ouput includes

\item{Penetrances}{the provided 3x3 penetrance matrix}
\item{Marginals}{length 3 vectors of the marginal pentrance conditional on the first locus and on the second locus}
\item{Prevalence}{expected prevalence of the dichotmoous phenotype}
\item{Var_ystar}{variance of the continuous variable underlying the phenotype}

For the normal model, the output instead includes

\item{Expected_Values}{a list with elements:

\code{Conditional} - a 3x3 matrix of the expected value of the phenotype by genotype

\code{MarginA} - length 3 vector of the marginal expected value conditional on the genotype of the first locus

\code{MarginB} - length 3 vector of the marginal expected value conditional on the genotype of the second locus

\code{Unconditional} - overall expected value of the phenotype}
\item{Var_y}{expected variance of the phenotype}
\item{error_variance}{variance of the (normally-distrbuted) error term for the phenotype}
}
\references{
Cockerham, C. C. (1954). An extension of the concept of partitioning hereditary variance for analysis of covariance among relatives when epistasis is present. \emph{Genetics}, 39: 859-882.

McKelvey, R., and Zavoina, W. (1975). A Statistical model for the analysis of ordinal level dependent variables. \emph{Journal of Mathematical Sociology}, 4: 103-120.

Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.}
\author{
Raymond Walters
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
To solve for the STACD parameters based on other information, see \code{\link{varex.to.stacd}} and \code{\link{pen.to.stacd}}.
}
\examples{
# define basic model information
betas <- c(0,0,0,0,0,0,.25,0,.5)
pa <- .3
pb <- .5

# get expected values, parameter decomposition
stacd.model(betas, pa, pb, model = "logistic")

# different output format for normal model
stacd.model(betas, pa, pb, model = "normal")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ models }
